function [L, U] = my_lu(A)
	% [L, U] = my_lu(A) 
	% Calcola una fattorizzazione LU di A

	n = size(A, 1);

	for i = 1:n
		% Salvo la i-esima colonna di L:
		L(:, i) = [zeros(i-1, 1); A(i:end, i) ./ A(i, i)];

		% Prodotto con matrice elementare L_i (non efficiente):
		% L_i = eye(n);
		% L_i(i+1:end, i) = - A(i+1:end, i) / A(i, i);
		% A = L_i * A;

		% Alternativa più efficiente: i-esimo passo di eliminazione gaussiana, corrispondente al prodotto con L_i: 
		A(i+1:end, i:end) = A(i+1:end, i:end) - A(i+1:end, i) * A(i, i:end) ./ A(i, i);
	end
	U = A;
end